==> tlmpwork-0.7.src.tar.gz: tlmpwork-0.7/framework/framework.pm <==
/* aboutbox.tlcc 08/04/2002 12.44.12 */
void _F_aboutbox::see_also (const char *, const char *);
void _F_aboutbox::printf (const char *ctl, ...);
void _F_aboutbox::setgpl (void);
/* _dict.cc 19/08/2000 22.25.10 */
/* framework.cc 31/10/2001 01.48.30 */
PUBLIC FRAMEWORK_MSGS::FRAMEWORK_MSGS (void);
PUBLIC void FRAMEWORK_MSGS::waitfor (DIALOG&dia);
PUBLIC bool FRAMEWORK_MSGS::is_ending (void);
PUBLIC bool FRAMEWORK_MSGS::is_mayend (void);
PUBLIC FRAMEWORK_INFO::FRAMEWORK_INFO (FRAMEWORK_MSGS&_msgs);
PUBLIC FRAMEWORK_INFO *FRAMEWORK_INFOS::getitem (int no)const;
PUBLIC FRAMEWORK_PRIVATE::FRAMEWORK_PRIVATE (void);
PUBLIC int FRAMEWORK_PRIVATE::getnbdocument (void);
PUBLIC void FRAMEWORK_PRIVATE::initfocus (FRAMEWORK_INFO *focus[6]);
void _F_FRAMEWORK::topmenu (const char *title);
void _F_FRAMEWORK::helpmenu (void);
void _F_FRAMEWORK::menuentry (int id, const char *title);
void _F_FRAMEWORK::submenu (const char *title);
void _F_FRAMEWORK::endmenu (void);
void _F_FRAMEWORK::newbutton (int id,
	 const char *icon,
	 const char *title,
	 const char *help);
void _F_FRAMEWORK::messages (void);
void _F_FRAMEWORK::taskbar (void);
void _F_FRAMEWORK::menubar (void);
void _F_FRAMEWORK::menudo (int ,
	 FRAMEWORK_INFOS[],
	 FRAMEWORK_INFO *[]);
void _F_FRAMEWORK::taskdo (int ,
	 FRAMEWORK_INFOS[],
	 FRAMEWORK_INFO *[]);
void _F_FRAMEWORK::call_area (int noarea, void *data);
void _F_FRAMEWORK::area1 (FRAMEWORK_INFO&info);
void _F_FRAMEWORK::area2 (FRAMEWORK_INFO&info);
void _F_FRAMEWORK::area3 (FRAMEWORK_INFO&info);
void _F_FRAMEWORK::area4 (FRAMEWORK_INFO&info);
void _F_FRAMEWORK::area5 (FRAMEWORK_INFO&info);
void _F_FRAMEWORK::document (int noarea, FRAMEWORK_INFO&info);
void _F_FRAMEWORK::newdocument (void *data, int noarea);
void _F_FRAMEWORK::newdocument (void *data);
void _F_FRAMEWORK::message (void);
void _F_FRAMEWORK::about (void);
void _F_FRAMEWORK::helpindex (void);
void _F_FRAMEWORK::nodocument (int , bool&end);
void _F_FRAMEWORK::status (PRIVATE_MESSAGE&);
void _F_FRAMEWORK::end (void);
void _F_FRAMEWORK::endok (void);
void _F_FRAMEWORK::layout_area (int noarea, bool isbook);
void _F_FRAMEWORK::layout_area1 (bool isbook);
void _F_FRAMEWORK::layout_area2 (bool isbook);
void _F_FRAMEWORK::layout_area3 (bool isbook);
void _F_FRAMEWORK::layout_area4 (bool isbook);
void _F_FRAMEWORK::layout_area5 (bool isbook);
void _F_FRAMEWORK::layout_end (void);
void _F_FRAMEWORK::pushid (char id[10]);
void _F_FRAMEWORK::layout_form (void);
void _F_FRAMEWORK::layout_group (const char *title);
void _F_FRAMEWORK::layout_book (void);
void _F_FRAMEWORK::layout_page (const char *title);
void _F_FRAMEWORK::layout_newline (void);
void _F_FRAMEWORK::layout_dispolast (GUI_H_DISPO hdisp,
	 int nbhcell,
	 GUI_V_DISPO vdisp,
	 int nbvcell);
void _F_FRAMEWORK::layout_cmd (int cmd, const char *ctl, ...);
void _F_FRAMEWORK::layout (void);
bool _F_FRAMEWORK::must_end (FRAMEWORK_MSGS&msgs);
PUBLIC void FRAMEWORK::manage (void);
PRIVATE void FRAMEWORK::init (_F_FRAMEWORK&_c,
	 const char *title,
	 PRIVATE_MESSAGE *msg,
	 FRAMEWORK_INFO *info);
PUBLIC FRAMEWORK::FRAMEWORK (_F_FRAMEWORK&_c,
	 const char *title,
	 PRIVATE_MESSAGE&msg);
PUBLIC FRAMEWORK::FRAMEWORK (_F_FRAMEWORK&_c, const char *title);
PUBLIC FRAMEWORK::FRAMEWORK (_F_FRAMEWORK&_c, FRAMEWORK_INFO&info);
PUBLIC FRAMEWORK::FRAMEWORK (_F_FRAMEWORK&_c,
	 const char *title,
	 FRAMEWORK_INFO&info);
PUBLIC void FRAMEWORK::newdocument (void *p, int noarea);
PUBLIC void FRAMEWORK::newdocument (void *p);
PUBLIC void FRAMEWORK::loop (void);
/* guilayout.cc 21/10/2000 22.57.20 */
void _F_guilayout::guiform (void);
void _F_guilayout::guibook (void);
void _F_guilayout::guigroup (const char *title);
void _F_guilayout::guigroupfit (const char *title);
void _F_guilayout::guiend (void);
void _F_guilayout::guinewline (void);
void _F_guilayout::guidispolast (GUI_H_DISPO hdisp,
	 int nbhcell,
	 GUI_V_DISPO vdisp,
	 int nbvcell);
void _F_guilayout::guicmd (int cmd, const char *ctl, ...);
void _F_guilayout::setuparea1 (bool atstartup);
void _F_guilayout::setuparea2 (bool atstartup);
void _F_guilayout::setuparea3 (bool atstartup);
void _F_guilayout::setuparea4 (bool atstartup);
void _F_guilayout::setuparea5 (bool atstartup);
void _F_guilayout::setuparea6 (bool atstartup);
void _F_guilayout::setuparea7 (bool atstartup);
void _F_guilayout::setuparea8 (bool atstartup);
void _F_guilayout::setuparea9 (bool atstartup);
void _F_guilayout::area3 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area4 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area5 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area6 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area7 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area8 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area9 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
int _F_guilayout::isareaalive (int noarea);
void _F_guilayout::callarea1 (void);
void _F_guilayout::callarea2 (void);
void _F_guilayout::callarea3 (void);
void _F_guilayout::callarea4 (void);
void _F_guilayout::callarea5 (void);
void _F_guilayout::callarea6 (void);
void _F_guilayout::callarea7 (void);
void _F_guilayout::callarea8 (void);
void _F_guilayout::callarea9 (void);
void _F_guilayout::endok (void);
/* objectsub.cc 19/09/2000 11.24.04 */
PUBLIC OBJECTSUB::OBJECTSUB (_F_OBJECTSUB&_c);
PUBLIC void OBJECTSUB::exec (void);
/* samples.tlcc 08/04/2002 12.44.12 */

==> tlmpwork-0.9.src.tar.gz: tlmpwork-0.9/framework/framework.pm <==
/* aboutbox.tlcc 02/06/2004 12.47.50 */
void _F_aboutbox::see_also (const char *, const char *);
void _F_aboutbox::printf (const char *ctl, ...);
void _F_aboutbox::setgpl (void);
/* _dict.cc 19/08/2000 22.25.10 */
/* framework.cc 02/06/2004 12.47.46 */
PUBLIC FRAMEWORK_MSGS_F::FRAMEWORK_MSGS_F (_F_FRAMEWORK&_c);
PUBLIC void FRAMEWORK_MSGS_F::endok (void);
PUBLIC FRAMEWORK_INFO::FRAMEWORK_INFO (FRAMEWORK_MSGS&_msgs);
PUBLIC FRAMEWORK_INFO *FRAMEWORK_INFOS::getitem (int no)const;
PUBLIC void FRAMEWORK_PRIVATE::adddoc (FRAMEWORK_DOCUMENT *doc);
PUBLIC void FRAMEWORK_PRIVATE::deldoc (FRAMEWORK_DOCUMENT *doc);
PUBLIC bool FRAMEWORK_PRIVATE::knowndoc (FRAMEWORK_DOCUMENT *doc);
PUBLIC FRAMEWORK_PRIVATE::FRAMEWORK_PRIVATE (_F_FRAMEWORK&_c);
PUBLIC int FRAMEWORK_PRIVATE::getnbdocument (void);
PUBLIC void FRAMEWORK_PRIVATE::initfocus (FRAMEWORK_INFO *focus[6]);
PUBLIC FRAMEWORK_INFO *FRAMEWORK_PRIVATE::getinfo (void);
void _F_FRAMEWORK::topmenu (const char *title);
void _F_FRAMEWORK::helpmenu (void);
void _F_FRAMEWORK::menuentry (int id, const char *title);
void _F_FRAMEWORK::submenu (const char *title);
void _F_FRAMEWORK::endmenu (void);
void _F_FRAMEWORK::newbutton (int id,
	 const char *icon,
	 const char *title,
	 const char *help);
void _F_FRAMEWORK::messages (void);
void _F_FRAMEWORK::ending (bool&);
void _F_FRAMEWORK::taskbar (void);
void _F_FRAMEWORK::menubar (void);
void _F_FRAMEWORK::menudo (int ,
	 FRAMEWORK_INFOS[],
	 FRAMEWORK_INFO *[]);
void _F_FRAMEWORK::taskdo (int ,
	 FRAMEWORK_INFOS[],
	 FRAMEWORK_INFO *[]);
void _F_FRAMEWORK::call_area (int noarea, void *data);
void _F_FRAMEWORK::area1 (FRAMEWORK_INFO&info);
void _F_FRAMEWORK::area2 (FRAMEWORK_INFO&info);
void _F_FRAMEWORK::area3 (FRAMEWORK_INFO&info);
void _F_FRAMEWORK::area4 (FRAMEWORK_INFO&info);
void _F_FRAMEWORK::area5 (FRAMEWORK_INFO&info);
void _F_FRAMEWORK::document (int noarea, FRAMEWORK_INFO&info);
PUBLIC int FRAMEWORK::getdocumentids (SSTRINGS&tb);
void _F_FRAMEWORK::newdocument (void *data, int noarea);
void _F_FRAMEWORK::newdocument (void *data);
void _F_FRAMEWORK::newdocument (void);
void _F_FRAMEWORK::newdocument (FRAMEWORK_DOCUMENT *data, int noarea);
void _F_FRAMEWORK::newdocument (FRAMEWORK_DOCUMENT *data);
void _F_FRAMEWORK::message (void);
void _F_FRAMEWORK::about (void);
void _F_FRAMEWORK::helpindex (void);
void _F_FRAMEWORK::nodocument (int , bool&end);
void _F_FRAMEWORK::status (PRIVATE_MESSAGE&);
void _F_FRAMEWORK::end (void);
void _F_FRAMEWORK::endok (void);
void _F_FRAMEWORK::layout_area (int noarea, bool isbook);
void _F_FRAMEWORK::layout_area1 (bool isbook);
void _F_FRAMEWORK::layout_area2 (bool isbook);
void _F_FRAMEWORK::layout_area3 (bool isbook);
void _F_FRAMEWORK::layout_area4 (bool isbook);
void _F_FRAMEWORK::layout_area5 (bool isbook);
void _F_FRAMEWORK::layout_end (void);
void _F_FRAMEWORK::pushid (char id[10]);
void _F_FRAMEWORK::layout_form (void);
void _F_FRAMEWORK::layout_group (const char *title);
void _F_FRAMEWORK::layout_book (void);
void _F_FRAMEWORK::layout_page (const char *title);
void _F_FRAMEWORK::layout_newline (void);
void _F_FRAMEWORK::layout_dispolast (GUI_H_DISPO hdisp,
	 int nbhcell,
	 GUI_V_DISPO vdisp,
	 int nbvcell);
void _F_FRAMEWORK::layout_cmd (int cmd, const char *ctl, ...);
void _F_FRAMEWORK::layout (void);
bool _F_FRAMEWORK::must_end (FRAMEWORK_MSGS&msgs);
bool _F_FRAMEWORK::must_end (void);
void _F_FRAMEWORK::waitforall (DIALOG&dia);
bool _F_FRAMEWORK::ismenuid (int menuid);
bool _F_FRAMEWORK::isclose (void);
bool _F_FRAMEWORK::istaskid (int taskid);
void _F_FRAMEWORK::setdocumentid (const char *s, ...);
PRIVATE void FRAMEWORK::sendmsg2focus (int menuid, int taskid);
PUBLIC void FRAMEWORK::manage (void);
PRIVATE void FRAMEWORK::init (_F_FRAMEWORK&_c,
	 const char *title,
	 PRIVATE_MESSAGE *msg,
	 FRAMEWORK_INFO *info);
PUBLIC FRAMEWORK::FRAMEWORK (_F_FRAMEWORK&_c,
	 const char *title,
	 PRIVATE_MESSAGE&msg);
PUBLIC FRAMEWORK::FRAMEWORK (_F_FRAMEWORK&_c, const char *title);
PUBLIC FRAMEWORK::FRAMEWORK (_F_FRAMEWORK&_c, FRAMEWORK_INFO&info);
PUBLIC FRAMEWORK::FRAMEWORK (_F_FRAMEWORK&_c,
	 const char *title,
	 FRAMEWORK_INFO&info);
PUBLIC void FRAMEWORK::newdocument (void *p, int noarea);
PUBLIC void FRAMEWORK::newdocument (void *p);
PUBLIC void FRAMEWORK::newdocument (void);
PUBLIC void FRAMEWORK::newdocument (FRAMEWORK_DOCUMENT *p, int noarea);
PUBLIC void FRAMEWORK::newdocument (FRAMEWORK_DOCUMENT *p);
PUBLIC void FRAMEWORK::loop (void);
/* guilayout.cc 21/10/2000 22.57.20 */
void _F_guilayout::guiform (void);
void _F_guilayout::guibook (void);
void _F_guilayout::guigroup (const char *title);
void _F_guilayout::guigroupfit (const char *title);
void _F_guilayout::guiend (void);
void _F_guilayout::guinewline (void);
void _F_guilayout::guidispolast (GUI_H_DISPO hdisp,
	 int nbhcell,
	 GUI_V_DISPO vdisp,
	 int nbvcell);
void _F_guilayout::guicmd (int cmd, const char *ctl, ...);
void _F_guilayout::setuparea1 (bool atstartup);
void _F_guilayout::setuparea2 (bool atstartup);
void _F_guilayout::setuparea3 (bool atstartup);
void _F_guilayout::setuparea4 (bool atstartup);
void _F_guilayout::setuparea5 (bool atstartup);
void _F_guilayout::setuparea6 (bool atstartup);
void _F_guilayout::setuparea7 (bool atstartup);
void _F_guilayout::setuparea8 (bool atstartup);
void _F_guilayout::setuparea9 (bool atstartup);
void _F_guilayout::area3 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area4 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area5 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area6 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area7 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area8 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
void _F_guilayout::area9 (PRIVATE_MESSAGE&, PRIVATE_MESSAGE&);
int _F_guilayout::isareaalive (int noarea);
void _F_guilayout::callarea1 (void);
void _F_guilayout::callarea2 (void);
void _F_guilayout::callarea3 (void);
void _F_guilayout::callarea4 (void);
void _F_guilayout::callarea5 (void);
void _F_guilayout::callarea6 (void);
void _F_guilayout::callarea7 (void);
void _F_guilayout::callarea8 (void);
void _F_guilayout::callarea9 (void);
void _F_guilayout::endok (void);
/* samples.tlcc 02/06/2004 12.47.50 */
/* statusbar.tlcc 02/06/2004 12.47.50 */
void _F_statusbar::settimer (int nbseconds);
void _F_statusbar::message (DIALOG&dia);
void _F_statusbar::timer (DIALOG&dia);
